summaryrefslogtreecommitdiffstats
path: root/chrome/browser/sync/protocol
diff options
context:
space:
mode:
authoralbertb@chromium.org <albertb@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-06-22 23:00:03 +0000
committeralbertb@chromium.org <albertb@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-06-22 23:00:03 +0000
commit376703e057fb55805c0d05c68a4b4d496e713ba7 (patch)
treebfc4043a291641063c43fa781cf69882aa7f6f05 /chrome/browser/sync/protocol
parent6d66bc2f295c5de6f6d28c1dd7e8d827459db1f4 (diff)
downloadchromium_src-376703e057fb55805c0d05c68a4b4d496e713ba7.zip
chromium_src-376703e057fb55805c0d05c68a4b4d496e713ba7.tar.gz
chromium_src-376703e057fb55805c0d05c68a4b4d496e713ba7.tar.bz2
TBR: willchan
git-svn-id: svn://svn.chromium.org/chrome/trunk/src@50541 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/sync/protocol')
-rw-r--r--chrome/browser/sync/protocol/password_specifics.proto11
1 files changed, 5 insertions, 6 deletions
diff --git a/chrome/browser/sync/protocol/password_specifics.proto b/chrome/browser/sync/protocol/password_specifics.proto
index efd3400b..4d1bc17 100644
--- a/chrome/browser/sync/protocol/password_specifics.proto
+++ b/chrome/browser/sync/protocol/password_specifics.proto
@@ -10,11 +10,10 @@ option optimize_for = LITE_RUNTIME;
package sync_pb;
-import "encryption.proto";
import "sync.proto";
// These are the properties that get serialized into the |encrypted| field of
// PasswordSpecifics.
message PasswordSpecificsData {
optional int32 scheme = 1;
optional string signon_realm = 2;
@@ -30,10 +29,10 @@ message PasswordSpecificsData {
optional bool blacklisted = 12;
}
-// Properties of password sync objects. The actual password data is held in a
-// PasswordSpecificsData that is encrypted into |encrypted|.
+// Properties of password sync objects.
message PasswordSpecifics {
- optional EncryptedData encrypted = 1;
+ optional string key = 1;
+ optional string blob = 2;
}
extend EntitySpecifics {
@@ -10,11 +10,10 @@ option optimize_for = LITE_RUNTIME;
import "sync.proto";
-// These are the properties that get serialized into the |encrypted| field of
-// PasswordSpecifics.
+// These are the properties that get serialized into the |blob| field of
+// |PasswordSpecifics|.
message PasswordSpecificsData {
optional int32 scheme = 1;